# comet
An AI-powered tool that transforms your Git workflow by generating concise, intelligent commit messages and seamlessly integrating with Jira for enhanced productivity and streamlined collaboration.
